@@ -288,8 +288,7 @@ but we'll only get strings from the LLM."
                                (unless (member mode '("org-mode" "markdown-mode" "text-mode"))
                                  (error "Unsupported mode: %s" mode))
                                ;; Use ekg-agent-add-note for consistency (includes auto-tags)
-                               (let ((note (ekg-agent-add-note content (append tags nil) mode)))
-                                 (format "Created note with ID %s" (ekg-note-id note)))))
+                               (format "Created note with ID %s" (ekg-agent-add-note content (append tags nil) mode))))
                  :name "create_note"
                  :description "Create a new note with specified tags and content."
                  :args `((:name "tags" :type array :items (:type string)
@@ -1506,6 +1505,7 @@ This function automatically:
 
 This is intended to be used from the command-line so agents can easily
 add properly formatted notes to ekg."
+  (ekg-connect)
   (let* ((mode-sym (if (stringp mode) (intern mode) mode))
          (enclosure (assoc-default mode-sym ekg-llm-format-output nil '("_BEGIN_" . "_END_")))
          (formatted-text (concat (car enclosure) "\n"
@@ -1534,7 +1534,8 @@ If MAX-WORDS is specified, truncate the text to that many words."
       (mode . ,(symbol-name (ekg-note-mode note)))
       (tags . ,(ekg-note-tags note))
       (creation_time . ,(ekg-note-creation-time note))
-      (modified_time . ,(ekg-note-modified-time note)))))
+      (modified_time . ,(ekg-note-modified-time note))
+      (properties . ,(ekg-note-properties note)))))
 
 (defun ekg-agent--notes-to-json (notes &optional max-words)
   "Convert list of NOTES to a JSON array string.
@@ -1561,6 +1562,7 @@ This function supports multiple modes of operation:
 NUM is the maximum number of notes to return (default 10).
 
 Returns a list of note objects."
+  (ekg-connect)
   (cond
    ;; Latest modified notes
    (latest
