@@ -31,6 +31,11 @@
 (require 'llm)
 (require 'ekg-agent)
 
+;; Forward declarations for variables defined later in this file.
+(defvar ekg-org-tool-add-task)
+(defvar ekg-org-tool-set-status)
+(defvar ekg-org-tool-list-items)
+
 (defconst ekg-org-state-tag-prefix "org/state/"
   "Prefix for EKG tags representing Org TODO states.")
 
@@ -227,6 +232,7 @@ Each level is indented to show the nesting structure."
 
 (defun ekg-org-agent-plan-task ()
   "Plan the current task and add the plan as child tasks using the agent."
+  (interactive)
   (let* ((ekg-note (ekg-current-note-or-error-expanded))
          (parent-id (ekg-note-id ekg-note))
          (parent-note (ekg-get-note-with-id parent-id))
